@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -98,40 +100,41 @@
 #'
 #' @examples
 #' # in Polish, ch < h:
-#' stri_cmp_lt("hladny", "chladny", locale="pl_PL")
+#' stri_cmp_lt('hladny', 'chladny', locale='pl_PL')
 #'
 #' # in Slovak, ch > h:
-#' stri_cmp_lt("hladny", "chladny", locale="sk_SK")
+#' stri_cmp_lt('hladny', 'chladny', locale='sk_SK')
 #'
 #' # < or > (depends on locale):
-#' stri_cmp("hladny", "chladny")
+#' stri_cmp('hladny', 'chladny')
 #'
 #' # ignore case differences:
-#' stri_cmp_equiv("hladny", "HLADNY", strength=2)
+#' stri_cmp_equiv('hladny', 'HLADNY', strength=2)
 #'
 #' # also ignore diacritical differences:
-#' stri_cmp_equiv("hladn\u00FD", "hladny", strength=1, locale="sk_SK")
+#' stri_cmp_equiv('hladn\u00FD', 'hladny', strength=1, locale='sk_SK')
 #'
 #' # non-Unicode-normalized vs normalized string:
-#' stri_cmp_equiv(stri_trans_nfkd("\u0105"), "\u105")
+#' stri_cmp_equiv(stri_trans_nfkd('\u0105'), '\u105')
 #'
 #' # note the difference:
-#' stri_cmp_eq(stri_trans_nfkd("\u0105"), "\u105")
+#' stri_cmp_eq(stri_trans_nfkd('\u0105'), '\u105')
 #'
 #' # ligatures:
-#' stri_cmp_equiv("\ufb00", "ff", strength=2)
+#' stri_cmp_equiv('\ufb00', 'ff', strength=2)
 #'
 #' # phonebook collation
-#' stri_cmp_equiv("G\u00e4rtner", "Gaertner", locale="de_DE@@collation=phonebook", strength=1L)
-#' stri_cmp_equiv("G\u00e4rtner", "Gaertner", locale="de_DE", strength=1L)
+#' stri_cmp_equiv('G\u00e4rtner', 'Gaertner', locale='de_DE@@collation=phonebook', strength=1L)
+#' stri_cmp_equiv('G\u00e4rtner', 'Gaertner', locale='de_DE', strength=1L)
 #'
 #' @family locale_sensitive
 #' @export
 #' @rdname stri_compare
-stri_compare <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp, e1, e2, opts_collator)
+stri_compare <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp, e1, e2, opts_collator)
 }
 
 
@@ -142,67 +145,75 @@ stri_cmp <- stri_compare
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_eq <- function(e1, e2) {
-   .Call(C_stri_cmp_eq, e1, e2)
+stri_cmp_eq <- function(e1, e2)
+{
+    .Call(C_stri_cmp_eq, e1, e2)
 }
 
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_neq <- function(e1, e2) {
-   .Call(C_stri_cmp_neq, e1, e2)
+stri_cmp_neq <- function(e1, e2)
+{
+    .Call(C_stri_cmp_neq, e1, e2)
 }
 
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_equiv <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_equiv, e1, e2, opts_collator)
+stri_cmp_equiv <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_equiv, e1, e2, opts_collator)
 }
 
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_nequiv <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_nequiv, e1, e2, opts_collator)
+stri_cmp_nequiv <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_nequiv, e1, e2, opts_collator)
 }
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_lt <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_lt, e1, e2, opts_collator)
+stri_cmp_lt <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_lt, e1, e2, opts_collator)
 }
 
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_gt <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_gt, e1, e2, opts_collator)
+stri_cmp_gt <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_gt, e1, e2, opts_collator)
 }
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_le <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_le, e1, e2, opts_collator)
+stri_cmp_le <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_le, e1, e2, opts_collator)
 }
 
 
 #' @export
 #' @rdname stri_compare
-stri_cmp_ge <- function(e1, e2, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_cmp_ge, e1, e2, opts_collator)
+stri_cmp_ge <- function(e1, e2, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_cmp_ge, e1, e2, opts_collator)
 }
 
 
@@ -211,7 +222,7 @@ stri_cmp_ge <- function(e1, e2, ..., opts_collator=NULL) {
 #'
 #' @description
 #' Relational operators for comparing corresponding strings in
-#' two character vectors, with a typical \R look-and-feel.
+#' two character vectors, with a typical R look-and-feel.
 #'
 #' @details
 #' These functions call \code{\link{stri_cmp_le}} or its
@@ -233,150 +244,167 @@ stri_cmp_ge <- function(e1, e2, ..., opts_collator=NULL) {
 #'
 #'
 #' @examples
-#' "a" %stri<% "b"
-#' c("a", "b", "c") %stri>=% "b"
+#' 'a' %stri<% 'b'
+#' c('a', 'b', 'c') %stri>=% 'b'
 #'
 #' @usage
 #' e1 \%s<\% e2
 #'
 #' @family locale_sensitive
-#' @rdname oper_comparison
+#' @rdname operator_compare
+#' @aliases operator_compare oper_comparison oper_compare
 #' @export
-"%s<%" <- function(e1, e2) {
-   stri_cmp_lt(e1, e2)
+"%s<%" <- function(e1, e2)
+{
+    stri_cmp_lt(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s<=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s<=%" <- function(e1, e2) {
-   stri_cmp_le(e1, e2)
+"%s<=%" <- function(e1, e2)
+{
+    stri_cmp_le(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s>\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s>%" <- function(e1, e2) {
-   stri_cmp_gt(e1, e2)
+"%s>%" <- function(e1, e2)
+{
+    stri_cmp_gt(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s>=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s>=%" <- function(e1, e2) {
-   stri_cmp_ge(e1, e2)
+"%s>=%" <- function(e1, e2)
+{
+    stri_cmp_ge(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s==\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s==%" <- function(e1, e2) {
-   stri_cmp_equiv(e1, e2)
+"%s==%" <- function(e1, e2)
+{
+    stri_cmp_equiv(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s!=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s!=%" <- function(e1, e2) {
-   stri_cmp_nequiv(e1, e2)
+"%s!=%" <- function(e1, e2)
+{
+    stri_cmp_nequiv(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s===\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s===%" <- function(e1, e2) {
-   stri_cmp_eq(e1, e2)
+"%s===%" <- function(e1, e2)
+{
+    stri_cmp_eq(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%s!==\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%s!==%" <- function(e1, e2) {
-   stri_cmp_neq(e1, e2)
+"%s!==%" <- function(e1, e2)
+{
+    stri_cmp_neq(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri<\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri<%" <- function(e1, e2) {
-   stri_cmp_lt(e1, e2)
+"%stri<%" <- function(e1, e2)
+{
+    stri_cmp_lt(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri<=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri<=%" <- function(e1, e2) {
-   stri_cmp_le(e1, e2)
+"%stri<=%" <- function(e1, e2)
+{
+    stri_cmp_le(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri>\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri>%" <- function(e1, e2) {
-   stri_cmp_gt(e1, e2)
+"%stri>%" <- function(e1, e2)
+{
+    stri_cmp_gt(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri>=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri>=%" <- function(e1, e2) {
-   stri_cmp_ge(e1, e2)
+"%stri>=%" <- function(e1, e2)
+{
+    stri_cmp_ge(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri==\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri==%" <- function(e1, e2) {
-   stri_cmp_equiv(e1, e2)
+"%stri==%" <- function(e1, e2)
+{
+    stri_cmp_equiv(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri!=\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri!=%" <- function(e1, e2) {
-   stri_cmp_nequiv(e1, e2)
+"%stri!=%" <- function(e1, e2)
+{
+    stri_cmp_nequiv(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri===\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri===%" <- function(e1, e2) {
-   stri_cmp_eq(e1, e2)
+"%stri===%" <- function(e1, e2)
+{
+    stri_cmp_eq(e1, e2)
 }
 
 
 #' @usage
 #' e1 \%stri!==\% e2
-#' @rdname oper_comparison
+#' @rdname operator_compare
 #' @export
-"%stri!==%" <- function(e1, e2) {
-   stri_cmp_neq(e1, e2)
+"%stri!==%" <- function(e1, e2)
+{
+    stri_cmp_neq(e1, e2)
 }
