@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -36,10 +38,10 @@
 #' Gives the list of encodings that are supported by \pkg{ICU}.
 #'
 #' @details
-#' Please note that apart from given encoding identifiers and their aliases,
-#' some other specifiers will be available in your conversion tasks.
+#' Apart from given encoding identifiers and their aliases,
+#' some other specifiers might be additionally available.
 #' This is due to the fact that \pkg{ICU} tries to normalize
-#' converter names. E.g. \code{"UTF8"} is also valid,
+#' converter names. For instance, \code{'UTF8'} is also valid,
 #' see \link{stringi-encoding} for more information.
 #'
 #' @param simplify single logical value; return a character vector or a
@@ -57,14 +59,15 @@
 #'
 #' @family encoding_management
 #' @export
-stri_enc_list <- function(simplify=FALSE) {
-   simplify <- !identical(simplify, FALSE)
+stri_enc_list <- function(simplify = FALSE)
+{
+    simplify <- !identical(simplify, FALSE)
 
-   ret <- .Call(C_stri_enc_list)
-   if (simplify)
-      return(stri_sort(unique(unlist(ret)))) # @TODO: use stri_unique
-   else
-      return(ret)
+    ret <- .Call(C_stri_enc_list)
+    if (simplify)
+        return(stri_sort(unique(unlist(ret))))  # @TODO: use stri_unique
+    else
+        return(ret)
 }
 
 
@@ -76,40 +79,41 @@ stri_enc_list <- function(simplify=FALSE) {
 #'
 #' @details
 #' An error is raised if the provided encoding is unknown to \pkg{ICU}
-#' (see \code{\link{stri_enc_list}} for more details)
+#' (see \code{\link{stri_enc_list}} for more details).
 #'
 #'
-#' @param enc \code{NULL} or \code{""} for default encoding,
+#' @param enc \code{NULL} or \code{''} for the default encoding,
 #' or a single string with encoding name
 #'
 #' @return
 #' Returns a list with the following components:
 #' \itemize{
-#' \item \code{Name.friendly} -- Friendly encoding name:
+#' \item \code{Name.friendly} -- friendly encoding name:
 #'     MIME Name or JAVA Name or \pkg{ICU} Canonical Name
 #'    (the first of provided ones is selected, see below);
-#' \item \code{Name.ICU} -- Encoding name as identified by \pkg{ICU};
+#' \item \code{Name.ICU} -- encoding name as identified by \pkg{ICU};
 #' \item \code{Name.*} -- other standardized encoding names,
-#' e.g. \code{Name.UTR22}, \code{Name.IBM}, \code{Name.WINDOWS},
+#' e.g., \code{Name.UTR22}, \code{Name.IBM}, \code{Name.WINDOWS},
 #' \code{Name.JAVA}, \code{Name.IANA}, \code{Name.MIME} (some of them
 #' may be unavailable for all the encodings);
 #' \item \code{ASCII.subset} -- is ASCII a subset of the given encoding?;
 #' \item \code{Unicode.1to1} -- for 8-bit encodings only: are all characters
 #' translated to exactly one Unicode code point and is the translation
 #' scheme reversible?;
-#' \item \code{CharSize.8bit} -- is this an 8-bit encoding, i.e. do we have
+#' \item \code{CharSize.8bit} -- is this an 8-bit encoding, i.e., do we have
 #'    \code{CharSize.min == CharSize.max} and \code{CharSize.min == 1}?;
 #' \item \code{CharSize.min} -- minimal number of bytes used
-#'    to represent an UChar (in UTF-16, this is not the same as UChar32)
+#'    to represent a UChar (in UTF-16, this is not the same as UChar32)
 #' \item \code{CharSize.max} -- maximal number of bytes used
-#'    to represent an UChar (in UTF-16, this is not the same as UChar32,
-#'    i.e. does not reflect the maximal code point representation size)
+#'    to represent a UChar (in UTF-16, this is not the same as UChar32,
+#'    i.e., does not reflect the maximal code point representation size)
 #' }
 #'
 #' @family encoding_management
 #' @export
-stri_enc_info <- function(enc=NULL) {
-   .Call(C_stri_enc_info, enc)
+stri_enc_info <- function(enc = NULL)
+{
+    .Call(C_stri_enc_info, enc)
 }
 
 
@@ -118,9 +122,9 @@ stri_enc_info <- function(enc=NULL) {
 #'
 #' @description
 #' \code{stri_enc_set} sets the encoding used to re-encode strings
-#' internally (i.e. by \R) declared to be in native encoding,
+#' internally (i.e., by \R) declared to be in native encoding,
 #' see \link{stringi-encoding} and \code{\link{stri_enc_mark}}.
-#' \code{stri_enc_get} returns currently used default encoding.
+#' \code{stri_enc_get} returns the currently used default encoding.
 #'
 #' @details
 #' \code{stri_enc_get} is the same as
@@ -138,6 +142,11 @@ stri_enc_info <- function(enc=NULL) {
 #' nor an 8-bit encoding, a warning will be generated,
 #' see \link{stringi-encoding} for discussion.
 #'
+#' \code{stri_enc_set} has no effect if the system ICU assumes that
+#' the default charset is always UTF-8 (i.e., where the internal
+#' \code{U_CHARSET_IS_UTF8} is defined and set to 1), see
+#' \code{\link{stri_info}}.
+#'
 #' @param enc single string; character encoding name,
 #' see \code{\link{stri_enc_list}} for the list of supported encodings.
 #'
@@ -151,21 +160,22 @@ stri_enc_info <- function(enc=NULL) {
 #' @family encoding_management
 #' @rdname stri_enc_set
 #' @export
-stri_enc_set <- function(enc) {
-   previous <- stri_enc_get()
+stri_enc_set <- function(enc)
+{
+    previous <- stri_enc_get()
 
-   # We call stri_info, because it generates some warnings,
-   # in case any problems are found:
-   .Call(C_stri_enc_set, enc)
-   message(stri_paste('You are now working with ', stri_info(short=TRUE)))
-   invisible(previous)
+    # We call stri_info, because it generates some warnings,
+    # in case any problems are found:
+    .Call(C_stri_enc_set, enc)
+    message(stri_paste("New settings: ", stri_info(short = TRUE)))
+    invisible(previous)
 }
 
 
 #' @rdname stri_enc_set
 #' @export
 stri_enc_get <- function() {
-   stri_enc_info(NULL)$Name.friendly
+    stri_enc_info(NULL)$Name.friendly
 }
 
 
@@ -173,7 +183,7 @@ stri_enc_get <- function() {
 #' Get Declared Encodings of Each String
 #'
 #' @description
-#' Gets declared encodings for each string in a character vector
+#' Reads declared encodings for each string in a character vector
 #' as seen by \pkg{stringi}.
 #'
 #' @details
@@ -182,17 +192,17 @@ stri_enc_get <- function() {
 #' strings can be declared to be in \code{latin1},
 #' \code{UTF-8} or \code{bytes}.
 #'
-#' Moreover, via the C API we may check whether
+#' Moreover, we may check (via the R/C API) whether
 #' a string is in ASCII (\R assumes that this holds if and only if
 #' all bytes in a string are not greater than 127,
 #' so there is an implicit assumption that your platform uses
-#' an encoding which is an ASCII superset)
+#' an encoding that extends ASCII)
 #' or in the system's default (a.k.a. \code{unknown} in \code{\link{Encoding}})
 #' encoding.
 #'
 #' Intuitively, the default encoding should be equivalent to
-#' the one you use when inputting data via keyboard.
-#' In \code{stringi} we assume that such an encoding
+#' the one you use on \code{stdin} (e.g., your 'keyboard').
+#' In \pkg{stringi} we assume that such an encoding
 #' is equivalent to the one returned by \code{\link{stri_enc_get}}.
 #' It is automatically detected by \pkg{ICU}
 #' to match -- by default -- the encoding part of the \code{LC_CTYPE} category
@@ -204,15 +214,16 @@ stri_enc_get <- function() {
 #' or an object coercible to a character vector
 #'
 #' @return Returns a character vector of the same length as \code{str}.
-#' Unlike in \code{\link{Encoding}}, possible encodings are:
+#' Unlike in the \code{\link{Encoding}} function, here the possible encodings are:
 #' \code{ASCII}, \code{latin1}, \code{bytes}, \code{native},
 #' and \code{UTF-8}. Additionally, missing values are handled properly.
 #'
-#' This is exactly the same information that is used by
+#' This gives exactly the same data that is used by
 #' all the functions in \pkg{stringi} to re-encode their inputs.
 #'
 #' @family encoding_management
 #' @export
-stri_enc_mark <- function(str) {
-   .Call(C_stri_enc_mark, str)
+stri_enc_mark <- function(str)
+{
+    .Call(C_stri_enc_mark, str)
 }
