@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,6 @@
 
 #define STRI__CONTINUE_ON_EMPTY_OR_NA_PATTERN(str_cont, pattern_cont, naset)                     \
       if ((str_cont).isNA(i) || (pattern_cont).isNA(i) || (pattern_cont).get(i).length() <= 0) { \
-         if ((!(pattern_cont).isNA(i)) && (pattern_cont).get(i).length() <= 0) {                 \
-            Rf_warning(MSG__EMPTY_SEARCH_PATTERN_UNSUPPORTED);                                   \
-         }                                                                                       \
          naset;                                                                                  \
          continue;                                                                               \
       }                                                                                          \
@@ -51,9 +48,6 @@
 
 #define STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(str_cont, pattern_cont, naset, zeroset)        \
       if ((str_cont).isNA(i) || (pattern_cont).isNA(i) || (pattern_cont).get(i).length() <= 0) { \
-         if ((!(pattern_cont).isNA(i)) && (pattern_cont).get(i).length() <= 0) {                 \
-            Rf_warning(MSG__EMPTY_SEARCH_PATTERN_UNSUPPORTED);                                   \
-         }                                                                                       \
          naset;                                                                                  \
          continue;                                                                               \
       }                                                                                          \
@@ -107,23 +101,55 @@
    (STRI__GET_INT32_LE(str_cur_s, 0) == 0x0000FEFFUL))
 
 
-// taken from R's Defn.h - sorry, this is needed
-// CHARSXP charset bits
+/* ************************************************************************
+ * based on R's Defn.h
+ * CHARSXP charset bits
+*/
+#ifndef BYTES_MASK
 #define BYTES_MASK (1<<1)
+#endif
+
+#ifndef LATIN1_MASK
 #define LATIN1_MASK (1<<2)
+#endif
+
+#ifndef UTF8_MASK
 #define UTF8_MASK (1<<3)
+#endif
+
+#ifndef ASCII_MASK
 #define ASCII_MASK (1<<6)
+#endif
+
+#ifndef IS_BYTES
 #define IS_BYTES(x) ((x)->sxpinfo.gp & BYTES_MASK)
+#endif
+
+#ifndef IS_LATIN1
 #define IS_LATIN1(x) ((x)->sxpinfo.gp & LATIN1_MASK)
+#endif
+
+#ifndef IS_ASCII
 #define IS_ASCII(x) ((x)->sxpinfo.gp & ASCII_MASK)
+#endif
+
+#ifndef IS_UTF8
 #define IS_UTF8(x) ((x)->sxpinfo.gp & UTF8_MASK)
+#endif
+
+#ifndef ENC_KNOWN
 #define ENC_KNOWN(x) ((x)->sxpinfo.gp & (LATIN1_MASK | UTF8_MASK | ASCII_MASK))
+#endif
 
+#ifndef isRaw
 #define isRaw(x) (TYPEOF(x) == RAWSXP)
+#endif
 
+/* ************************************************************************ */
 
-/// Unicode replacement character
+/* Unicode replacement character */
 #define UCHAR_REPLACEMENT 0xFFFD
+
 #define ASCII_SUBSTITUTE  0x1A
 #define ASCII_MAXCHARCODE 127
 #define UCHAR_REPLACEMENT_UTF8_BYTE1 0xef
